@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 1.9.0 (2021-10-16)
+   Version: 2.0.0 (2021-10-16)
    Website: http://www.gingerblue.org/
 
  */
@@ -88,11 +88,8 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	gchar *filename = NULL;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
 	GstElementFactory *factory;
-
 	gst_element_send_event(recorder, gst_event_new_eos());
-
 	recorder = gst_pipeline_new("record_pipe");
-
 	/*
 	  FIXME: Line #59 from https://github.com/GStreamer/gst-plugins-base/blob/master/tools/gst-device-monitor.c
 	  element = gst_device_create_element (device, NULL);
@@ -173,11 +170,6 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
 			g_date_time_format_iso8601 (datestamp), "]",
 			".gingerblue", NULL);
-	g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
-			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
-			g_date_time_format_iso8601 (datestamp), "]",
-			".ogg", NULL);
 	fp = fopen(filename, "w");
 	fprintf(fp, "<?xml version='1.0' encoding='UTF-8'?>\n");
 	fprintf(fp, "<gingerblue version='%s'>\n", VERSION);
@@ -269,6 +261,7 @@ int main(int argc, char **argv)
 		{NULL, -1, "Album", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Broadcasting", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
 	};
+	FILE *xspf = NULL;
 	datestamp = g_date_time_new_now_utc ();
 	gchar *filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 				      gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
@@ -361,7 +354,7 @@ int main(int argc, char **argv)
 		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	g_signal_connect(G_OBJECT(studio_entry), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
-		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+			 gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	page[8].widget = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(page[8].widget), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	gtk_box_pack_start(GTK_BOX(page[8].widget), GTK_WIDGET(studio_label),
@@ -373,9 +366,7 @@ int main(int argc, char **argv)
 	g_signal_connect(G_OBJECT(album_label), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
 			 gtk_entry_get_text(GTK_ENTRY(album_entry)));
-	album = g_strconcat(gtk_entry_get_text(GTK_ENTRY(studio_entry)),
-			       gtk_entry_get_text(GTK_ENTRY(label_entry)),
-			       ".pls", NULL);
+	album = g_strconcat(g_get_user_special_dir (G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), NULL);
 	gtk_entry_set_text(GTK_ENTRY(album_entry), (gchar *)album);
 	page[9].widget = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(page[9].widget), album);
@@ -530,6 +521,18 @@ int main(int argc, char **argv)
 
 	g_date_time_unref (datestamp);
 
+	xspf = fopen(g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL), "w+");
+	fprintf(xspf, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
+	fprintf(xspf, "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n");
+	fprintf(xspf, "<trackList>\n");
+	fprintf(xspf, "<track>\n");
+	fprintf(xspf, g_strconcat("<title>", gtk_entry_get_text(GTK_ENTRY(song_entry)), "</title>\n", NULL));
+	fprintf(xspf, g_strconcat("<location>file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "</location>\n", NULL));
+	fprintf(xspf, "</track>\n");
+	fprintf(xspf, "</trackList>\n");
+	fprintf(xspf, "</playlist>\n");
+	fclose(xspf);
+
 	gtk_main();
 	return (0);
 }
